#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_content.shared.resource import IAgeRange, IResourceInfo, IWfResource
from pyams_default_theme import _
from pyams_default_theme import lightbox
from pyams_default_theme.features.search.portlet import ISearchResultRenderer, WfSharedContentSearchResultRenderer
from pyams_default_theme.interfaces import ISearchResultsView
from pyams_default_theme.shared.common.interfaces import ICustomContentSpecificitiesParagraphRenderer, \
    ICustomContentSpecificitiesRenderer
from pyams_i18n.interfaces import II18n
from pyams_skin.layer import IPyAMSUserLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.text import text_to_html
from pyams_viewlet.viewlet import ViewContentProvider


@adapter_config(context=(IWfResource, IPyAMSUserLayer, Interface),
                provides=ICustomContentSpecificitiesRenderer)
@adapter_config(context=(IWfResource, IPyAMSUserLayer, Interface),
                provides=ICustomContentSpecificitiesParagraphRenderer)
@template_config(template='templates/specificities.pt', layer=IPyAMSUserLayer)
class ResourceSpecificitiesPortletRenderer(ViewContentProvider):
    """Resource specificities portlet renderer"""

    resources = (lightbox,)

    @property
    def resource_info(self):
        return IResourceInfo(self.context)

    def get_age_range(self, value: IAgeRange):
        translate = self.request.localizer.translate
        if value.min_value and value.max_value:
            result = _("from {0.min_value} to {0.max_value}")
        elif value.min_value:
            result = _("from {0.min_value}")
        else:
            result = _("up to {0.max_value}")
        return translate(result).format(value)


@adapter_config(context=(IWfResource, IPyAMSUserLayer, ISearchResultsView), provides=ISearchResultRenderer)
@template_config(template='templates/search-result.pt', layer=IPyAMSUserLayer)
class WfResourceSearchResultRenderer(WfSharedContentSearchResultRenderer):
    """Resource search result renderer"""

    @property
    def header(self):
        header = II18n(self.context).query_attribute('header', request=self.request)
        if header:
            return text_to_html(header)
        return ''
